@@ -45,11 +45,16 @@ def execute(
     df = df.astype(str)
 
     data = {"program": program, "cono": 409}
+
+    mylist = []
     data1 = {}
+    data2 = {}
     a = []
 
     chunk = MaxChunk
     if end is not None:
+        # total_rows = end - start
+        counter = 0
         df = df[start:end].copy(deep=False)
         df = df.reset_index(drop=True)
         # print (df.head(10))
@@ -119,11 +124,16 @@ def executeSnd(
     data = {"program": program, "cono": 409}
 
     methode = methode.split(",")
-    len(methode)
+    methode_count = len(methode)
+
+    mylist = []
     data1 = {}
+    data2 = {}
 
     chunk = MaxChunk
     if end is not None:
+        # total_rows = end - start
+        counter = 0
         df = df[start:end].copy(deep=False)
         df = df.reset_index(drop=True)
 
@@ -178,9 +188,16 @@ def executeAsyncSnd(
     data = {"program": program, "cono": 409}
 
     methode = methode.split(",")
-    len(methode)
+    methode_count = len(methode)
+
+    mylist = []
     data1 = {}
+    data2 = {}
+
+    chunk = MaxChunk
     if end is not None:
+        # total_rows = end - start
+        counter = 0
         df = df[start:end].copy(deep=False)
         df = df.reset_index(drop=True)
         # print (df.head(10))
@@ -230,7 +247,7 @@ def executeAsyncSnd(
 
 def getSuccessGraphDataframe(df):
     results = {}
-    for _, row in df.iterrows():
+    for index, row in df.iterrows():
         msgs = row['MESSAGE'].split('|')
         for msg in msgs:
             if(msg):
